@@ -61,7 +61,7 @@ qx.Class.define("callbackery.ui.Login", {
         var grid = new qx.ui.layout.Grid(10, 10);
         this.setLayout(grid);
         grid.setColumnAlign(1, 'right', 'middle');
-        let logoScale = (cfg.logo_scale != undefined) ? cfg.logo_scale : true;
+        let logoScale = ! cfg.logo_noscale;
         let logoSpan  = logoScale ? 3 : 1; 
         if (cfg.logo){
             this.add(new qx.ui.basic.Image(cfg.logo).set({
